/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is written by Juan Lang.
 *
 * The Initial Developer of the Original Code is 
 * Juan Lang.
 * Portions created by the Initial Developer are Copyright (C) 2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or 
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */
#ifndef __IFDETECT_H__
#define __IFDETECT_H__

#include "nspr.h"

#define MAX_DHCP_HWADDR 16

typedef enum {
  InterfaceHWTypeUnknown = 0,
  InterfaceHWTypeEthernet = 1,
} InterfaceHWType;

/* Represents an interface.  Members:
 * name: the interface's name, which may be NULL; free with PL_strfree
 * hwType: the type of the interface to be used with DHCP; the values are the
 * the same as ARP uses, and don't necessarily imply this is the _real_ type
 * of the interface (e.g. TokenRing uses InterfaceHWTypeEthernet)
 * hwAddrLen: the length of the hwAddr member (not to exceed MAX_DHCP_HWADDR)
 * hwAddr: the interface's hardware (MAC) address
 * ip: the interface's IPv4 address
 * bcastAddr: the interface's broadcast address
 * serverAddr: the IPv4 address of the DHCP server address that granted the
 * interface its IP address, if known (and PR_INADDR_ANY otherwise).
 * addrExpires: the time the interface's DHCP lease expires, if known, and 0
 * otherwise
 * sock: for your use
 * next: a pointer to the next interface in the list
 */
struct InterfaceInfo
{
  char *name;
  InterfaceHWType hwType;
  PRUint32 hwAddrLen;
  PRUint8 hwAddr[MAX_DHCP_HWADDR];
  PRUint32 ip;
  PRUint32 bcastAddr;
  PRUint32 serverAddr;
  PRIntn sock;
  struct InterfaceInfo *next;
};

#ifdef __cplusplus
extern "C" {
#endif

/* Returns linked list of InterfaceInfo's describing each DHCP interface.
 * You must do a deep free of the returned array; using freeInterfaceList is
 * the better way to do it.
 * A bit of a misnomer under UNIX, this function finds all the up broadcast
 * interfaces with IP addresses on your system.  (It can't tell whether they
 * were configured using DHCP.  I've written a shell script that does this;
 * use it in conjunction with this.)
 */
struct InterfaceInfo *findDHCPInterfaces(void);

/* Frees a list created by findDHCPInterfaces.
 */
void freeInterfaceList(struct InterfaceInfo *list);

#ifdef __cplusplus
}
#endif

#endif /* ndef __IFDETECT_H__ */
